import os

import collections
import pkg_resources
import pytest
import vcr
import yaml

from helix import HelixApp, HelixClient, HelixEventHandlerInterface


class CounterEventHandler(HelixEventHandlerInterface):
    def __init__(self):
        self.counter = collections.Counter()

    def accountUpdate(self, app, event):
        self.counter[event["eventType"]] += 1

    def sampleStatusUpdate(self, app, event):
        self.counter[event["eventType"]] += 1

    def accessRevoked(self, app, event):
        self.counter[event["eventType"]] += 1



app_name = "egoitis"
env = "staging"
apps = yaml.load(pkg_resources.resource_stream("helix", "_data/apps.yml"))
credentials = yaml.load(pkg_resources.resource_stream("helix", "_data/credentials.yml"))


@pytest.fixture(scope="session")
def client():
    return HelixClient(env=env, credentials=credentials[app_name])


@pytest.fixture(scope="function")
def app(client):
    return HelixApp(
        client=client,
        handler=CounterEventHandler(),
        after=0,
        config=apps[app_name],
        ignore_unknown_event_types=True)
        

test_dir = os.path.dirname(__file__)
test_data_dir = os.path.join(test_dir, "data", "cassettes")

vcr.default_vcr = vcr.VCR(
    cassette_library_dir=test_data_dir,
    filter_headers=["Authorization"],
    filter_post_data_parameters=['Authorization'],
    record_mode=os.environ.get("VCR_RECORD_MODE", "none"),
    )
vcr.use_cassette = vcr.default_vcr.use_cassette
