import time

import vcr

# only pacid with customer and sample status:
pacid = "PC-VCIOSK47ERXXIBPO5ZBOMW2HSNCQETCY"


def test_init(client):
    pass


def test_str(client):
    assert str(client).startswith("HelixClient(")


@vcr.use_cassette
def test_get_events(client):
    # test expected event structure
    event = next(client.get_events(after=0))
    for k in []:
        assert k in event
    assert event["pacId"].startswith("PC-")

    # test filtering
    event_type = "accountUpdate"
    event = next(client.get_events(after=0, event_type=event_type))
    assert event["eventType"] == event_type

    # test after + until logic
    # [{'eventType': 'accountUpdate',
    #   'pacId': 'PC-VCIOSK47ERXXIBPO5ZBOMW2HSNCQETCY',
    #   'sequenceNum': 126,
    #   'timestamp': '2016-08-15T21:21:24Z'},
    #  {'eventType': 'accountUpdate',
    #   'pacId': 'PC-VCIOSK47ERXXIBPO5ZBOMW2HSNCQETCY',
    #   'sequenceNum': 127,
    #   'timestamp': '2016-08-16T00:36:39Z'}]
    events = list(client.get_events(after=120, until="2016-08-15T21:21:24Z"))
    last_event = events[-1]
    assert last_event["sequenceNum"] == 126
    events = list(client.get_events(after=last_event["sequenceNum"], until="2017-01-01T00:00:00"))
    assert events[0]["sequenceNum"] == 127

    
    old_ai = client._authinfos["identity"]
    old_ai.expires_at = time.time()  # force refresh now
    next(client.get_events(after=0))
    new_ai = client._authinfos["identity"]
    assert old_ai.access_token != new_ai.access_token


@vcr.use_cassette
def test_get_customer(client):
    # only pacid with customer and sample status:
    customer = client.get_customer(pacid)
    for k in ["email", "firstName", "lastName", "supportId"]:
        assert k in customer

    
@vcr.use_cassette
def test_get_sample_status(client):
    status_events = client.get_sample_status(pacid)
    for k in ["status", "timestamp"]:
        assert k in status_events[0]


@vcr.use_cassette
def test_get_variants(client):
    variants = client.get_variants(pacid)
    for k in ['calls', 'end', 'referenceName', 'variantSetId',
              'alternateBases', 'start', 'referenceBases', 'id']:
        assert k in variants[0]

